==> dojo-1.9.4.tgz: package/cldr/nls/ko/hebrew.js <==
define(
//begin v1.x content
{
	"field-dayperiod": "오전/오후",
	"dateFormatItem-yyyyMMMEd": "G y년 MMM d일 (E)",
	"dayPeriods-format-wide-pm": "오후",
	"field-minute": "분",
	"dateFormatItem-MMMEd": "MMM d일 (E)",
	"field-day-relative+-1": "어제",
	"field-weekday": "요일",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-day-relative+-2": "그저께",
	"field-era": "연호",
	"dateFormatItem-Gy": "G y년",
	"field-hour": "시",
	"dayPeriods-format-wide-am": "오전",
	"dateFormatItem-y": "G y년",
	"timeFormat-full": "a h시 m분 s초 zzzz",
	"dateFormatItem-yyyy": "G y년",
	"dateFormatItem-Ed": "d일 (E)",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"days-standAlone-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"eraAbbr": [
		"AM"
	],
	"field-day-relative+2": "모레",
	"dateFormatItem-GyMMMd": "G y년 MMM d일",
	"dateFormat-long": "G y년 M월 d일",
	"timeFormat-medium": "a h:mm:ss",
	"field-zone": "시간대",
	"field-week-relative+-1": "지난주",
	"dateFormat-medium": "G y. M. d.",
	"dateFormatItem-Hms": "H시 m분 s초",
	"field-year-relative+0": "올해",
	"field-year-relative+1": "내년",
	"field-year-relative+-1": "지난해",
	"field-year": "년",
	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
	"field-week": "주",
	"dateFormatItem-yyyyMd": "G y. M. d.",
	"dateFormatItem-yyyyMMMd": "G y년 MMM d일",
	"dateFormatItem-yyyyMEd": "G y. M. d. (E)",
	"dateFormatItem-MMMd": "MMM d일",
	"field-week-relative+0": "이번 주",
	"field-week-relative+1": "다음 주",
	"timeFormat-long": "a h시 m분 s초 z",
	"field-month-relative+0": "이번 달",
	"field-month": "월",
	"field-month-relative+1": "다음 달",
	"dateFormatItem-H": "H시",
	"timeFormat-short": "a h:mm",
	"quarters-format-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"days-format-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-M": "M월",
	"field-second": "초",
	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
	"dateFormatItem-GyMMM": "G y년 MMM",
	"field-day": "일",
	"dateFormatItem-yyyyQQQ": "G y년 QQQ",
	"dateFormatItem-MEd": "M. d. (E)",
	"days-standAlone-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-hm": "a h:mm",
	"dateFormat-short": "G y. M. d.",
	"dateFormatItem-yyyyM": "G y. M.",
	"dateFormatItem-Md": "M. d.",
	"dateFormat-full": "G y년 M월 d일 EEEE",
	"days-format-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-yyyyMMM": "G y년 MMM",
	"dateFormatItem-d": "d일",
	"field-month-relative+-1": "지난달",
	"quarters-format-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"days-format-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"dateFormatItem-h": "a h시"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/ko/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"field-second-relative+0": "지금",
	"field-weekday": "요일",
	"field-wed-relative+0": "이번 수요일",
	"field-wed-relative+1": "다음 수요일",
	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
	"dateFormatItem-MMMEd": "MMM d일 (E)",
	"field-tue-relative+-1": "지난 화요일",
	"days-format-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormat-long": "G y년 M월 d일",
	"field-fri-relative+-1": "지난 금요일",
	"field-wed-relative+-1": "지난 수요일",
	"dateFormatItem-yyyyQQQ": "G y년 QQQ",
	"dayPeriods-format-wide-pm": "오후",
	"dateFormat-full": "G y년 M월 d일 EEEE",
	"dateFormatItem-yyyyMEd": "G y. M. d. (E)",
	"field-thu-relative+-1": "지난 목요일",
	"dateFormatItem-Md": "M. d.",
	"field-era": "연호",
	"months-standAlone-wide": [
		"디스리월",
		"말케스월",
		"기슬르월",
		"데벳월",
		"스밧월",
		"아달월 1",
		"아달월",
		"닛산월",
		"이야르월",
		"시완월",
		"담무르월",
		"압월",
		"엘룰월"
	],
	"timeFormat-short": "a h:mm",
	"quarters-format-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"timeFormat-long": "a h시 m분 s초 z",
	"field-year": "년",
	"field-hour": "시",
	"months-format-abbr-leap": "아달월 2",
	"months-format-abbr": [
		"디스리월",
		"말케스월",
		"기슬르월",
		"데벳월",
		"스밧월",
		"아달월 1",
		"아달월",
		"닛산월",
		"이야르월",
		"시완월",
		"담무르월",
		"압월",
		"엘룰월"
	],
	"field-sat-relative+0": "이번 토요일",
	"field-sat-relative+1": "다음 토요일",
	"timeFormat-full": "a h시 m분 s초 zzzz",
	"field-day-relative+0": "오늘",
	"field-thu-relative+0": "이번 목요일",
	"field-day-relative+1": "내일",
	"field-thu-relative+1": "다음 목요일",
	"dateFormatItem-GyMMMd": "G y년 MMM d일",
	"field-day-relative+2": "모레",
	"dateFormatItem-H": "H시",
	"months-standAlone-abbr": [
		"디스리월",
		"말케스월",
		"기슬르월",
		"데벳월",
		"스밧월",
		"아달월 1",
		"아달월",
		"닛산월",
		"이야르월",
		"시완월",
		"담무르월",
		"압월",
		"엘룰월"
	],
	"quarters-format-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"quarters-standAlone-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"dateFormatItem-Gy": "G y년",
	"dateFormatItem-yyyyMMMEd": "G y년 MMM d일 (E)",
	"dateFormatItem-M": "M월",
	"dateFormatItem-yyyyMMM": "G y년 MMM",
	"dateFormatItem-yyyyMMMd": "G y년 MMM d일",
	"months-standAlone-wide-leap": "아달월 2",
	"timeFormat-medium": "a h:mm:ss",
	"field-sun-relative+0": "이번 일요일",
	"field-sun-relative+1": "다음 일요일",
	"quarters-standAlone-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"eraAbbr": [
		"AM"
	],
	"field-minute": "분",
	"field-dayperiod": "오전/오후",
	"dateFormatItem-d": "d일",
	"field-day-relative+-1": "어제",
	"dateFormatItem-h": "a h시",
	"field-day-relative+-2": "그저께",
	"dateFormatItem-MMMd": "MMM d일",
	"dateFormatItem-MEd": "M. d. (E)",
	"field-fri-relative+0": "이번 금요일",
	"field-fri-relative+1": "다음 금요일",
	"field-day": "일",
	"days-format-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"field-zone": "시간대",
	"months-standAlone-abbr-leap": "아달월 2",
	"dateFormatItem-y": "G y년",
	"field-year-relative+-1": "작년",
	"field-month-relative+-1": "지난달",
	"dateFormatItem-hm": "a h:mm",
	"days-format-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-yyyyMd": "G y. M. d.",
	"field-month": "월",
	"days-standAlone-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"field-tue-relative+0": "이번 화요일",
	"field-tue-relative+1": "다음 화요일",
	"dayPeriods-format-wide-am": "오전",
	"field-mon-relative+0": "이번 월요일",
	"field-mon-relative+1": "다음 월요일",
	"dateFormat-short": "G y. M. d.",
	"field-second": "초",
	"field-sat-relative+-1": "지난 토요일",
	"field-sun-relative+-1": "지난 일요일",
	"field-month-relative+0": "이번 달",
	"field-month-relative+1": "다음 달",
	"dateFormatItem-Ed": "d일 (E)",
	"field-week": "주",
	"dateFormat-medium": "G y. M. d.",
	"field-year-relative+0": "올해",
	"field-week-relative+-1": "지난주",
	"dateFormatItem-yyyyM": "G y. M.",
	"field-year-relative+1": "내년",
	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
	"dateFormatItem-Hms": "H시 m분 s초",
	"dateFormatItem-hms": "a h:mm:ss",
	"dateFormatItem-GyMMM": "G y년 MMM",
	"field-mon-relative+-1": "지난 월요일",
	"dateFormatItem-yyyy": "G y년",
	"field-week-relative+0": "이번 주",
	"field-week-relative+1": "다음 주"
}
//end v1.x content
);
